==> immutable-collection-encodings-1.4-sources.jar: com/hubspot/immutable/collection/encoding/ImmutableMapEncodingEnabled.java <==
package com.hubspot.immutable.collection.encoding;

import org.immutables.encode.EncodingMetadata;

@EncodingMetadata(
  name = "com.hubspot.immutable.collection.encoding.ImmutableMapEncoding",
  imports = {
  },
  typeParams = {"K", "V"},
  elements = {
    @EncodingMetadata.Element(
      name = "field",
      tags = {"IMPL", "PRIVATE", "FINAL", "FIELD"},
      naming = "*",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableMap<K, V>",
      typeParams = {},
      params = {},
      code = "com.google.common.collect.ImmutableMap.of()",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "of",
      tags = {"STATIC", "PRIVATE", "FROM"},
      naming = "*_of",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableMap<K, V>",
      typeParams = {},
      params = {"input: java.util.Map<? extends K, ? extends V>"},
      code = "{\nreturn com.google.common.collect.ImmutableMap.copyOf(@^input);\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "toString",
      tags = {"PRIVATE", "TO_STRING", "SYNTH"},
      naming = "*_toString",
      stdNaming = "NONE",
      type = "java.lang.String",
      typeParams = {},
      params = {},
      code = "{\nreturn @:getImmutableMap().toString();\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "hashCode",
      tags = {"PRIVATE", "HASH_CODE", "SYNTH"},
      naming = "*_hashCode",
      stdNaming = "NONE",
      type = "int",
      typeParams = {},
      params = {},
      code = "{\nreturn @:getImmutableMap().hashCode();\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "equals",
      tags = {"PRIVATE", "EQUALS", "SYNTH"},
      naming = "*_equals",
      stdNaming = "NONE",
      type = "java.lang.String",
      typeParams = {},
      params = {"other: com.hubspot.immutable.collection.encoding.ImmutableMapEncoding<K, V>"},
      code = "{\nreturn this.@:getImmutableMap().equals(@^other.@:getImmutableMap())\n;}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "build",
      tags = {"BUILDER", "PRIVATE", "BUILD"},
      naming = "*_build",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableMap<K, V>",
      typeParams = {},
      params = {},
      code = "{\nif (@@builder != null) {\nreturn @@builder.build();\n} else if (@@map != null) {\nreturn @@map;\n} else {\nreturn com.google.common.collect.ImmutableMap.of();\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "getImmutableMap",
      tags = {"EXPOSE"},
      naming = "*",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableMap<K, V>",
      typeParams = {},
      params = {},
      code = "{\nreturn @@field;\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "getMap",
      tags = {"EXPOSE"},
      naming = "*",
      stdNaming = "NONE",
      type = "java.util.Map<K, V>",
      typeParams = {},
      params = {},
      code = "{\nreturn @@field;\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "withCollection",
      tags = {"COPY"},
      naming = "*",
      stdNaming = "WITH",
      type = "com.google.common.collect.ImmutableMap<K, V>",
      typeParams = {},
      params = {"elements: java.util.Map<K, ? extends V>"},
      code = "{\nreturn com.google.common.collect.ImmutableMap.copyOf(@^elements);\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "map",
      tags = {"BUILDER", "PRIVATE", "FIELD"},
      naming = "*_map",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableMap<K, V>",
      typeParams = {},
      params = {},
      code = "null",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "builder",
      tags = {"BUILDER", "PRIVATE", "FIELD"},
      naming = "*_builder",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableMap.Builder<K, V>",
      typeParams = {},
      params = {},
      code = "null",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "put",
      tags = {"BUILDER", "INIT"},
      naming = "*",
      stdNaming = "PUT",
      type = "void",
      typeParams = {},
      params = {"key: K", "value: V"},
      code = "{\nif (@@builder != null) {\n@@builder.put(@^key, @^value);\n} else if (@@map != null) {\n@@builder = com.google.common.collect.ImmutableMap.<@^K, @^V>builderWithExpectedSize(@@map.size() + 1)\n.putAll(@@map)\n.put(@^key, @^value);\n@@map = null;\n} else {\n@@builder = com.google.common.collect.ImmutableMap.builder();\n@@builder.put(@^key, @^value);\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "putEntry",
      tags = {"BUILDER", "INIT"},
      naming = "*",
      stdNaming = "PUT",
      type = "void",
      typeParams = {},
      params = {"entry: java.util.Map.Entry<K, ? extends V>"},
      code = "{\nif (@@builder != null) {\n@@builder.put(@^entry);\n} else if (@@map != null) {\n@@builder = com.google.common.collect.ImmutableMap.<@^K, @^V>builderWithExpectedSize(@@map.size() + 1)\n.putAll(@@map)\n.put(@^entry);\n@@map = null;\n} else {\n@@builder = com.google.common.collect.ImmutableMap.builder();\n@@builder.put(@^entry);\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "putAll",
      tags = {"BUILDER", "INIT"},
      naming = "*",
      stdNaming = "PUT_ALL",
      type = "void",
      typeParams = {},
      params = {"elements: java.util.Map<K, ? extends V>"},
      code = "{\nif (@@builder != null) {\n@@builder.putAll(@^elements);\n} else if (@@map != null) {\n@@builder = com.google.common.collect.ImmutableMap.<@^K, @^V>builderWithExpectedSize(@@map.size() + @^elements.size())\n.putAll(@@map)\n.putAll(@^elements);\n@@map = null;\n} else {\nif (@^elements instanceof com.google.common.collect.ImmutableMap) {\n@:set(@^elements);\n} else {\n@@builder = com.google.common.collect.ImmutableMap.builderWithExpectedSize(@^elements.size());\n@@builder.putAll(@^elements);\n}\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "set",
      tags = {"BUILDER", "INIT", "COPY"},
      naming = "*",
      stdNaming = "INIT",
      type = "void",
      typeParams = {},
      params = {"input: java.util.Map<K, ? extends V>"},
      code = "{\n@@map = com.google.common.collect.ImmutableMap.copyOf(@^input);\n@@builder = null;\n}",
      thrown = {}
    )
  }
)
public @interface ImmutableMapEncodingEnabled {}

==> immutable-collection-encodings-1.11.0-sources.jar: com/hubspot/immutable/collection/encoding/ImmutableMapEncodingEnabled.java <==
package com.hubspot.immutable.collection.encoding;

import org.immutables.encode.EncodingMetadata;

@EncodingMetadata(
  name = "com.hubspot.immutable.collection.encoding.ImmutableMapEncoding",
  imports = {
  },
  typeParams = {"K", "V"},
  elements = {
    @EncodingMetadata.Element(
      name = "field",
      tags = {"IMPL", "PRIVATE", "FINAL", "FIELD"},
      naming = "*",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableMap<K, V>",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "null",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "of",
      tags = {"STATIC", "PRIVATE", "FROM"},
      naming = "*_of",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableMap<K, V>",
      typeParams = {},
      params = {"input: java.util.Map<? extends K, ? extends V>"},
      doc = {},
      annotations = {},
      code = "{\nreturn com.google.common.collect.ImmutableMap.copyOf(@^input);\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "toString",
      tags = {"PRIVATE", "TO_STRING", "SYNTH"},
      naming = "*_toString",
      stdNaming = "NONE",
      type = "java.lang.String",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "{\nreturn @:getImmutableMap().toString();\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "hashCode",
      tags = {"PRIVATE", "HASH_CODE", "SYNTH"},
      naming = "*_hashCode",
      stdNaming = "NONE",
      type = "int",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "{\nreturn @:getImmutableMap().hashCode();\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "equals",
      tags = {"PRIVATE", "EQUALS", "SYNTH"},
      naming = "*_equals",
      stdNaming = "NONE",
      type = "java.lang.String",
      typeParams = {},
      params = {"other: com.hubspot.immutable.collection.encoding.ImmutableMapEncoding<K, V>"},
      doc = {},
      annotations = {},
      code = "{\nreturn this.@:getImmutableMap().equals(@^other.@:getImmutableMap())\n;}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "build",
      tags = {"BUILDER", "PRIVATE", "BUILD"},
      naming = "*_build",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableMap<K, V>",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "{\nif (@@builder != null) {\nreturn @@builder.build();\n} else if (@@map != null) {\nreturn @@map;\n} else {\nreturn com.google.common.collect.ImmutableMap.of();\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "isSet",
      tags = {"BUILDER", "PRIVATE", "IS_INIT"},
      naming = "*_isSet",
      stdNaming = "NONE",
      type = "boolean",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "{\nreturn @@map != null || @@builder != null;\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "getImmutableMap",
      tags = {"EXPOSE"},
      naming = "*",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableMap<K, V>",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "{\nif (@@field != null) {\nreturn @@field;\n} else {\nreturn com.google.common.collect.ImmutableMap.of();\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "getMap",
      tags = {"EXPOSE"},
      naming = "*",
      stdNaming = "NONE",
      type = "java.util.Map<K, V>",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "{\nif (@@field != null) {\nreturn @@field;\n} else {\nreturn com.google.common.collect.ImmutableMap.of();\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "withCollection",
      tags = {"COPY"},
      naming = "*",
      stdNaming = "WITH",
      type = "com.google.common.collect.ImmutableMap<K, V>",
      typeParams = {},
      params = {"elements: java.util.Map<K, ? extends V>"},
      doc = {},
      annotations = {},
      code = "{\nreturn com.google.common.collect.ImmutableMap.copyOf(@^elements);\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "map",
      tags = {"BUILDER", "PRIVATE", "FIELD"},
      naming = "*_map",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableMap<K, V>",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "null",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "builder",
      tags = {"BUILDER", "PRIVATE", "FIELD"},
      naming = "*_builder",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableMap.Builder<K, V>",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "null",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "put",
      tags = {"BUILDER", "INIT"},
      naming = "*",
      stdNaming = "PUT",
      type = "void",
      typeParams = {},
      params = {"key: K", "value: V"},
      doc = {},
      annotations = {},
      code = "{\nif (@@builder != null) {\n@@builder.put(@^key, @^value);\n} else if (@@map != null) {\n@@builder =\ncom.google.common.collect.ImmutableMap\n.<@^K, @^V>builderWithExpectedSize(@@map.size() + 1)\n.putAll(@@map)\n.put(@^key, @^value);\n@@map = null;\n} else {\n@@builder = com.google.common.collect.ImmutableMap.builder();\n@@builder.put(@^key, @^value);\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "putEntry",
      tags = {"BUILDER", "INIT"},
      naming = "*",
      stdNaming = "PUT",
      type = "void",
      typeParams = {},
      params = {"entry: java.util.Map.Entry<K, ? extends V>"},
      doc = {},
      annotations = {},
      code = "{\nif (@@builder != null) {\n@@builder.put(@^entry);\n} else if (@@map != null) {\n@@builder =\ncom.google.common.collect.ImmutableMap\n.<@^K, @^V>builderWithExpectedSize(@@map.size() + 1)\n.putAll(@@map)\n.put(@^entry);\n@@map = null;\n} else {\n@@builder = com.google.common.collect.ImmutableMap.builder();\n@@builder.put(@^entry);\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "putAll",
      tags = {"BUILDER", "INIT"},
      naming = "*",
      stdNaming = "PUT_ALL",
      type = "void",
      typeParams = {},
      params = {"elements: java.util.Map<K, ? extends V>"},
      doc = {},
      annotations = {},
      code = "{\nif (@@builder != null) {\n@@builder.putAll(@^elements);\n} else if (@@map != null) {\n@@builder =\ncom.google.common.collect.ImmutableMap\n.<@^K, @^V>builderWithExpectedSize(@@map.size() + @^elements.size())\n.putAll(@@map)\n.putAll(@^elements);\n@@map = null;\n} else {\nif (@^elements instanceof com.google.common.collect.ImmutableMap) {\n@:set(@^elements);\n} else {\n@@builder = com.google.common.collect.ImmutableMap.builderWithExpectedSize(@^elements.size());\n@@builder.putAll(@^elements);\n}\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "set",
      tags = {"BUILDER", "INIT", "COPY"},
      naming = "*",
      stdNaming = "INIT",
      type = "void",
      typeParams = {},
      params = {"input: java.util.Map<K, ? extends V>"},
      doc = {},
      annotations = {},
      code = "{\n@@map = com.google.common.collect.ImmutableMap.copyOf(@^input);\n@@builder = null;\n}",
      thrown = {}
    )
  }
)
public @interface ImmutableMapEncodingEnabled {}
